@@ -1,3 +1,5 @@
+use crate::pda::PDA;
+
 use anchor_lang::prelude::*;
 use anchor_lang::AccountDeserialize;
 use std::convert::TryFrom;
@@ -19,3 +21,9 @@ impl TryFrom<Vec<u8>> for Config {
         Config::try_deserialize(&mut data.as_slice())
     }
 }
+
+impl Config {
+    pub fn find_pda() -> PDA {
+        Pubkey::find_program_address(&[SEED_CONFIG], &crate::ID)
+    }
+}
